==> qtcreator_4.5.2.orig.tar.xz: qt-creator-opensource-src-4.5.2/src/plugins/autotest/qtest/qttestsettingspage.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "ui_qttestsettingspage.h"

#include "../itestsettingspage.h"

#include <QPointer>

namespace Autotest {
namespace Internal {

class IFrameworkSettings;
class QtTestSettings;

class QtTestSettingsWidget : public QWidget
{
    Q_OBJECT
public:
    explicit QtTestSettingsWidget(QWidget *parent = 0);

    void setSettings(const QtTestSettings &settings);
    QtTestSettings settings() const;

private:
    Ui::QtTestSettingsPage m_ui;
};

class QtTestSettingsPage : public ITestSettingsPage
{
    Q_OBJECT
public:
    QtTestSettingsPage(QSharedPointer<IFrameworkSettings> settings, const ITestFramework *framework);

    QWidget *widget() override;
    void apply() override;
    void finish() override { }

private:
    QSharedPointer<QtTestSettings> m_settings;
    QPointer<QtTestSettingsWidget> m_widget;
};

} // namespace Internal
} // namespace Autotest

==> qtcreator_4.11.0.orig.tar.xz: qt-creator-opensource-src-4.11.0/src/plugins/autotest/qtest/qttestsettingspage.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "ui_qttestsettingspage.h"

#include "../itestsettingspage.h"

#include <QPointer>

namespace Autotest {

class IFrameworkSettings;

namespace Internal {

class QtTestSettings;

class QtTestSettingsWidget : public QWidget
{
    Q_OBJECT

public:
    QtTestSettingsWidget();

    void setSettings(const QtTestSettings &settings);
    QtTestSettings settings() const;

private:
    Ui::QtTestSettingsPage m_ui;
};

class QtTestSettingsPage : public ITestSettingsPage
{
    Q_OBJECT
public:
    QtTestSettingsPage(QSharedPointer<IFrameworkSettings> settings, const ITestFramework *framework);

    QWidget *widget() override;
    void apply() override;

private:
    QSharedPointer<QtTestSettings> m_settings;
    QPointer<QtTestSettingsWidget> m_widget;
};

} // namespace Internal
} // namespace Autotest
